@@ -184,7 +184,7 @@ from ..file import File
 
 class Environment(object):
 
-    _CONFIG_FILENAME = "/usr/local/share/texmf/web2c/texmf.cnf"
+    _CONFIG_FILENAME = "/usr/local/share/texmf-dist/web2c/texmf.cnf"
     _DEFAULT_TEXMF_DIR = "/usr/local/share/texmf"
     _DEFAULT_TEXMF_DIR_HOME = "~/texmf"
 
@@ -323,7 +323,7 @@ class Environment(object):
             # no files found
             self._log.error("No %s-files found in %s%s" % (extension, search_path, relative))
 
-        for name, label in labels.iteritems():
+        for name, label in labels.items():
             found = False
             for resource in resources:
                 if resource.name == name:
